@@ -30,9 +30,9 @@ from gi.repository import Gdk
 from gi.repository import Pango
 from gi.repository import WebKit2
 from gi.repository import Soup
-from gi.repository import GConf
+from gi.repository import Gio
 
-from sugar3.activity import activity
+from sugar3.activity.activity import get_bundle_path, get_activity_root
 from sugar3.graphics import style
 from sugar3.graphics.icon import Icon
 from sugar3.graphics.alert import Alert, ConfirmationAlert
@@ -64,18 +64,20 @@ _NON_SEARCH_REGEX = re.compile('''
     ''', re.VERBOSE)
 _HOSTNAME_REGEX = re.compile('[a-z]+://([^/]+)/.*')
 
-DEFAULT_ERROR_PAGE = os.path.join(activity.get_bundle_path(),
+DEFAULT_ERROR_PAGE = os.path.join(get_bundle_path(),
                                   'data/error_page.tmpl')
 
-HOME_PAGE_GCONF_KEY = '/desktop/sugar/browser/home_page'
+SETTINGS_SCHEMA_ID = 'org.laptop.WebActivity'
+SETTINGS_KEY_HOME_PAGE = 'home-page'
 
 TAB_BROWSER = 'browser'
 TAB_PDF = 'pdf'
 
 _sugar_version = None
+_settings = None
 
 
-def get_sugar_version():
+def _get_sugar_version():
     global _sugar_version
     if _sugar_version is None:
         if 'SUGAR_VERSION' in os.environ:
@@ -89,6 +91,47 @@ def get_sugar_version():
     return _sugar_version
 
 
+def _get_local_settings(activity):
+    """ return an activity-specific Gio.Settings
+    """
+    global _settings
+    if _settings is None:
+
+        # create schemas directory if missing
+        path = os.path.join(get_activity_root(), 'data', 'schemas')
+        if not os.access(path, os.F_OK):
+            os.makedirs(path)
+
+        # create compiled schema file if missing
+        compiled = os.path.join(path, 'gschemas.compiled')
+        if not os.access(compiled, os.R_OK):
+            src = '%s.gschema.xml' % activity.get_bundle_id()
+            lines = \
+                [
+                    '<?xml version="1.0" encoding="UTF-8"?>',
+                    '<schemalist>',
+                    '<schema id="org.laptop.WebActivity" '
+                    'path="/org/laptop/WebActivity/">',
+                    '<key name="home-page" type="s">',
+                    "<default>''</default>",
+                    '<summary>Home page URL</summary>',
+                    '<description>URL to show as default or when home button '
+                    'is pressed.</description>',
+                    '</key>',
+                    '</schema>',
+                    '</schemalist>',
+                ]
+            open(os.path.join(path, src), 'w').writelines(lines)
+            os.system('glib-compile-schemas %s' % path)
+            os.remove(os.path.join(path, src))
+
+        # create a local Gio.Settings based on the compiled schema
+        source = Gio.SettingsSchemaSource.new_from_directory(path, None, True)
+        schema = source.lookup(SETTINGS_SCHEMA_ID, True)
+        _settings = Gio.Settings.new_full(schema, None, None)
+    return _settings
+
+
 class TabbedView(BrowserNotebook):
     __gtype_name__ = 'TabbedView'
 
@@ -101,6 +144,7 @@ class TabbedView(BrowserNotebook):
     def __init__(self, activity):
         self._activity = activity
         BrowserNotebook.__init__(self)
+        self.settings = _get_local_settings(activity)
         self.props.show_border = False
         self.props.scrollable = True
 
@@ -159,6 +203,7 @@ class TabbedView(BrowserNotebook):
 
         soup_uri = None
         effective_url = None
+        url = url.lstrip()
 
         if has_web_scheme(url):
             try:
@@ -341,7 +386,7 @@ class TabbedView(BrowserNotebook):
         if isinstance(tab_page, PDFTabPage):
             tab_page.cancel_download()
 
-        # ensure that a tab opened because of click on 
+        # ensure that a tab opened because of click on
         # <a href="something" target="name">this</a>
         # can be closed and then opened again
         # (WebKit is keeping the WebView object alive)
@@ -400,30 +445,27 @@ class TabbedView(BrowserNotebook):
             for page in pages_pdf + pages_html:
                 self.get_tab_label(page).show_close_button()
 
-    def load_homepage(self, ignore_gconf=False):
+    def load_homepage(self, ignore_settings=False):
         browser = self.current_browser
-        uri_homepage = None
-        if not ignore_gconf:
-            client = GConf.Client.get_default()
-            uri_homepage = client.get_string(HOME_PAGE_GCONF_KEY)
-        if uri_homepage is not None:
-            browser.load_uri(uri_homepage)
+        home_page = None
+        if not ignore_settings:
+            home_page = self.settings.get_string(SETTINGS_KEY_HOME_PAGE)
+        if home_page != '':
+            browser.load_uri(home_page)
         elif os.path.isfile(LIBRARY_PATH):
             browser.load_uri('file://' + LIBRARY_PATH)
         else:
-            default_page = os.path.join(activity.get_bundle_path(),
+            default_page = os.path.join(get_bundle_path(),
                                         "data/index.html")
             browser.load_uri('file://' + default_page)
         browser.grab_focus()
 
     def set_homepage(self):
         uri = self.current_browser.get_uri()
-        client = GConf.Client.get_default()
-        client.set_string(HOME_PAGE_GCONF_KEY, uri)
+        self.settings.set_string(SETTINGS_KEY_HOME_PAGE, uri)
 
     def reset_homepage(self):
-        client = GConf.Client.get_default()
-        client.unset(HOME_PAGE_GCONF_KEY)
+        self.settings.reset(SETTINGS_KEY_HOME_PAGE)
 
     def _get_current_browser(self):
         if self.get_n_pages():
@@ -606,6 +648,8 @@ class TabLabel(Gtk.HBox):
             if widget.props.title is None:
                 self._label.set_text(_('Untitled'))
                 self._title = _('Untitled')
+            else:
+                self._label.set_text(self._title)
         else:
             self._label.set_text(_('Loading...'))
 
@@ -625,7 +669,7 @@ class Browser(WebKit2.WebView):
                                     ([])),
     }
 
-    CURRENT_SUGAR_VERSION = get_sugar_version()
+    CURRENT_SUGAR_VERSION = _get_sugar_version()
 
     SECURITY_STATUS_SECURE = 1
     SECURITY_STATUS_INSECURE = 2
@@ -750,7 +794,7 @@ class Browser(WebKit2.WebView):
             async_err_cb()
 
         def writer(view, result):
-            temp_path = os.path.join(activity.get_activity_root(), 'instance')
+            temp_path = os.path.join(get_activity_root(), 'instance')
             file_path = os.path.join(temp_path, '%i' % time.time())
 
             file_handle = file(file_path, 'w')
@@ -758,7 +802,7 @@ class Browser(WebKit2.WebView):
             file_handle.close()
             async_cb(file_path)
 
-        data = self.get_main_resource().get_data(None, writer)
+        self.get_main_resource().get_data(None, writer)
 
     def open_new_tab(self, url):
         self.emit('new-tab', url)
@@ -846,7 +890,7 @@ class Browser(WebKit2.WebView):
                 WebKit2.PolicyError.FRAME_LOAD_INTERRUPTED_BY_POLICY_CHANGE,
                 WebKit2.PluginError.WILL_HANDLE_LOAD):
             if self._inject_media_style:
-                css_style_file = open(os.path.join(activity.get_bundle_path(),
+                css_style_file = open(os.path.join(get_bundle_path(),
                                                    "data/media-controls.css"))
                 css_style = css_style_file.read().replace('\n', '')
                 inject_style_script = \
@@ -875,10 +919,10 @@ class Browser(WebKit2.WebView):
     def _get_permission_name(self, request):
         if hasattr(WebKit2, 'GeolocationPermissionRequest') and \
            isinstance(request, WebKit2.GeolocationPermissionRequest):
-            return _('access to your location')
+            return _('receive your location')
         if hasattr(WebKit2, 'NotificationPermissionRequest') and \
            isinstance(request, WebKit2.NotificationPermissionRequest):
-            return _('to display notifications in the frame')
+            return _('display notifications in the frame')
         # Should never be reached
         return type(request).__name__
 
@@ -890,8 +934,8 @@ class Browser(WebKit2.WebView):
             site = match.group(1)
 
         alert = ConfirmationAlert()
-        alert.props.title = _('Allow %s to %s?') % \
-            (site, description)
+        alert.props.title = _('Allow %{site} to %{description}?') % \
+            {'site': site, 'description': description}
         alert.props.msg = _(
             'You can change your choice later by reloading the page')
         alert.connect('response', self.__permission_request_alert_cb, request)
