@@ -23,15 +23,19 @@ import os
 
 import gi
 gi.require_version('Gtk', '3.0')
-gi.require_version('WebKit2', '4.0')
+try:
+    incompatible = False
+    gi.require_version('WebKit2', '4.0')
+except:
+    incompatible = True
 gi.require_version('SoupGNOME', '2.4')
-gi.require_version('GConf', '2.0')
 
 from gi.repository import GObject
 GObject.threads_init()
 
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gio
 from gi.repository import WebKit2
 from gi.repository import Soup
 from gi.repository import SoupGNOME
@@ -40,22 +44,22 @@ from base64 import b64decode, b64encode
 import time
 import shutil
 import json
-from gi.repository import GConf
 import cairo
 import StringIO
 from hashlib import sha1
 
 from sugar3.activity import activity
+from sugar3.activity.widgets import StopButton
 from sugar3.graphics import style
 from sugar3.graphics.alert import Alert
 from sugar3.graphics.alert import NotifyAlert
 from sugar3.graphics.icon import Icon
 from sugar3.graphics.animator import Animator, Animation
 from sugar3 import mime
-from sugar3.graphics.toolbarbox import ToolbarButton
+from sugar3.graphics.toolbarbox import ToolbarBox, ToolbarButton
 from sugar3 import profile
 
-from collabwrapper.collabwrapper import CollabWrapper
+from collabwrapper import CollabWrapper
 from widgets import TitledTray
 
 
@@ -98,14 +102,14 @@ def _seed_xs_cookie(cookie_jar):
     if the cookie already exists.
 
     """
-    client = GConf.Client.get_default()
-    backup_url = client.get_string('/desktop/sugar/backup_url')
+    settings = Gio.Settings('org.sugarlabs')
+    backup_url = settings.get_string('backup-url')
     if not backup_url:
         _logger.debug('seed_xs_cookie: Not registered with Schoolserver')
         return
 
-    jabber_server = client.get_string(
-        '/desktop/sugar/collaboration/jabber_server')
+    settings = Gio.Settings('org.sugarlabs.collaboration')
+    jabber_server = settings.get_string('jabber-server')
 
     soup_uri = Soup.URI()
     soup_uri.set_scheme('xmpp')
@@ -133,7 +137,6 @@ def _seed_xs_cookie(cookie_jar):
 
 
 from browser import TabbedView
-from browser import ZOOM_ORIGINAL
 from webtoolbar import PrimaryToolbar
 from edittoolbar import EditToolbar
 from viewtoolbar import ViewToolbar
@@ -154,6 +157,11 @@ _logger = logging.getLogger('web-activity')
 class WebActivity(activity.Activity):
     def __init__(self, handle):
         activity.Activity.__init__(self, handle)
+
+        self._force_close = False
+        if incompatible:
+            return self._incompatible()
+
         self._collab = CollabWrapper(self)
         self._collab.message.connect(self.__message_cb)
 
@@ -181,7 +189,6 @@ class WebActivity(activity.Activity):
         # downloadmanager.remove_old_parts()
         context.connect('download-started', self.__download_requested_cb)
 
-        self._force_close = False
         self._tabbed_view = TabbedView(self)
         self._tabbed_view.connect('focus-url-entry', self._on_focus_url_entry)
         self._tabbed_view.connect('switch-page', self.__switch_page_cb)
@@ -247,13 +254,17 @@ class WebActivity(activity.Activity):
         downloadmanager.add_download(download, self)
         return True
 
+    def fullscreen(self):
+        activity.Activity.fullscreen(self)
+        self._tabbed_view.set_show_tabs(False)
+
     def unfullscreen(self):
         activity.Activity.unfullscreen(self)
 
         # Always show tabs here, because they are automatically hidden
         # if it is like a video fullscreening.  We ALWAYS need to make
         # sure these are visible.  Don't make the user lost
-        self._tabbed_view.props.show_tabs = True
+        self._tabbed_view.set_show_tabs(True)
 
     def _cleanup_temp_files(self):
         """Removes temporary files generated by Download Manager that
@@ -351,7 +362,7 @@ class WebActivity(activity.Activity):
 
     def write_file(self, file_path):
         if not hasattr(self, '_tabbed_view'):
-            _logger.error('Called write_file before the tabbed_view was made')
+            _logger.debug('Called write_file before the tabbed_view was made')
             return
 
         if not self.metadata['mime_type']:
@@ -361,7 +372,7 @@ class WebActivity(activity.Activity):
             browser = self._tabbed_view.current_browser
 
             if not self._jobject.metadata['title_set_by_user'] == '1' and \
-                not self._get_save_as():
+               not self._get_save_as():
                 if browser.props.title is None:
                     self.metadata['title'] = _('Untitled')
                 else:
@@ -406,7 +417,7 @@ class WebActivity(activity.Activity):
         self._tabbed_view.load_homepage()
 
     def _go_library_button_cb(self, button):
-        self._tabbed_view.load_homepage(ignore_gconf=True)
+        self._tabbed_view.load_homepage(ignore_settings=True)
 
     def _set_home_button_cb(self, button):
         self._tabbed_view.set_homepage()
@@ -665,6 +676,46 @@ class WebActivity(activity.Activity):
     def get_canvas(self):
         return self._tabbed_view
 
+    def _incompatible(self):
+        ''' Display abbreviated activity user interface with alert '''
+        toolbox = ToolbarBox()
+        stop = StopButton(self)
+        toolbox.toolbar.add(stop)
+        self.set_toolbar_box(toolbox)
+
+        title = _('Activity not compatible with this system.')
+        msg = _('Please downgrade activity and try again.')
+        alert = Alert(title=title, msg=msg)
+        alert.add_button(0, 'Stop', Icon(icon_name='activity-stop'))
+        self.add_alert(alert)
+
+        label = Gtk.Label(_('Uh oh, WebKit2 is too old. '
+                            'Browse-200 and later require WebKit2 API 4.0, '
+                            'sorry!'))
+        self.set_canvas(label)
+
+        '''
+        Workaround: start Terminal activity, then type
+
+        sugar-erase-bundle org.laptop.WebActivity
+
+        then in My Settings, choose Software Update, which will offer
+        older Browse.
+        '''
+
+        alert.connect('response', self.__incompatible_response_cb)
+        stop.connect('clicked', self.__incompatible_stop_clicked_cb,
+                         alert)
+
+        self.show_all()
+
+    def __incompatible_stop_clicked_cb(self, button, alert):
+        self.remove_alert(alert)
+
+    def __incompatible_response_cb(self, alert, response):
+        self.remove_alert(alert)
+        self.close()
+
 
 class AddLinkAnimation(Animation):
 
