@@ -23,10 +23,9 @@ from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import GLib
 from gi.repository import Gdk
-from gi.repository import GConf
+from gi.repository import Gio
 from gi.repository import Pango
 
-import sugar3.profile
 from sugar3.graphics.toolbutton import ToolButton
 from sugar3.graphics.toggletoolbutton import ToggleToolButton
 from sugar3.graphics import iconentry
@@ -36,17 +35,12 @@ from sugar3.graphics.palettemenu import PaletteMenuBox
 from sugar3.graphics import style
 from sugar3.activity.widgets import ActivityToolbarButton
 from sugar3.activity.widgets import StopButton
-from sugar3.datastore import datastore
-from sugar3.activity import activity
-from sugar3.graphics.alert import Alert
-from sugar3.graphics.icon import Icon
 
-import tempfile
 import filepicker
 import places
 import downloadmanager
 from browser import Browser
-from browser import HOME_PAGE_GCONF_KEY, LIBRARY_PATH
+from browser import SETTINGS_KEY_HOME_PAGE, LIBRARY_PATH
 from progresstoolbutton import ProgressToolButton
 
 from pdfviewer import DummyBrowser
@@ -117,7 +111,7 @@ class WebEntry(iconentry.IconEntry):
         self._search_window = _SearchWindow()
         self._search_window_scroll = Gtk.ScrolledWindow()
         self._search_window_scroll.set_policy(Gtk.PolicyType.NEVER,
-                                Gtk.PolicyType.AUTOMATIC)
+                                              Gtk.PolicyType.AUTOMATIC)
         self._search_window_scroll.set_min_content_height(200)
         self._search_window_scroll.add(self._search_view)
         self._search_window.add(self._search_window_scroll)
@@ -269,7 +263,6 @@ class WebEntry(iconentry.IconEntry):
         path = (selection.get_selected_rows()[1])[0]
         index = path.get_indices()[0]
         adjustment = self._search_window_scroll.get_vadjustment()
-        value = adjustment.get_value()
         step = style.STANDARD_ICON_SIZE
         adjustment.set_value(step * index)
         self._search_window_scroll.set_vadjustment(adjustment)
@@ -390,9 +383,8 @@ class PrimaryToolbar(ToolbarBase):
         menu_box.show_all()
 
         # verify if the home page is configured
-        client = GConf.Client.get_default()
-        self._reset_home_menu.set_visible(
-            client.get_string(HOME_PAGE_GCONF_KEY) is not None)
+        home_page = tabbed_view.settings.get_string(SETTINGS_KEY_HOME_PAGE)
+        self._reset_home_menu.set_visible(home_page != '')
 
         toolbar.insert(self._go_home, -1)
         self._go_home.show()
@@ -660,11 +652,15 @@ class PrimaryToolbar(ToolbarBase):
                                       'entry-cancel')
 
     def _update_navigation_buttons(self):
-        can_go_back = self._browser.can_go_back()
-        self._back.props.sensitive = can_go_back
+        if isinstance(self._browser, Browser):
+            can_go_back = self._browser.can_go_back()
+            self._back.props.sensitive = can_go_back
 
-        can_go_forward = self._browser.can_go_forward()
-        self._forward.props.sensitive = can_go_forward
+            can_go_forward = self._browser.can_go_forward()
+            self._forward.props.sensitive = can_go_forward
+        else:
+            self._back.props.sensitive = False
+            self._forward.props.sensitive = False
 
         is_webkit_browser = isinstance(self._browser, Browser)
         self._go_home.props.sensitive = is_webkit_browser
@@ -811,6 +807,13 @@ class PrimaryToolbar(ToolbarBase):
             inspector.attach()
 
     '''
+    import sugar3.profile
+    from sugar3.datastore import datastore
+    from sugar3.activity import activity
+    from sugar3.graphics.alert import Alert
+    from sugar3.graphics.icon import Icon
+    import tempfile
+
     def save_as_pdf(self, widget):
         tmp_dir = os.path.join(self._activity.get_activity_root(), 'tmp')
         fd, file_path = tempfile.mkstemp(dir=tmp_dir)
